package org.rcisoft.business.memInfo.dao;

import org.rcisoft.business.cmsActivity.entity.CmsActivity;
import org.rcisoft.business.memInfo.entity.*;
import org.rcisoft.core.mapper.CyBaseMapper;
import org.apache.ibatis.annotations.ResultMap;
import org.apache.ibatis.annotations.Select;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.sys.rbac.user.dto.SysUserRbacDTO;
import org.springframework.stereotype.Repository;
import org.rcisoft.core.model.CyPageInfo;
import org.apache.ibatis.annotations.Param;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.time.LocalDate;
import java.util.List;
import java.util.Map;

/**
* Created with cy on 2024年12月20日 下午3:35:34.
*/

public interface MemInfoRepository extends CyBaseMapper<MemInfo> {


    List<MemInfo> queryMemInfos(@Param("entity") MemInfo memInfo);

    /**
    * 分页查询 memInfo
    *
    */
    IPage<MemInfo> queryMemInfosPaged(CyPageInfo cyPageInfo,@Param("entity") MemInfo memInfo);

    /**
     * 根据roleKey查询角色
     * @param roleKey
     * @return
     */
    List<Integer> selectRoleByKey(@Param("roleKey")String roleKey);

    //校验手机号是否重复
    SysUserRbacDTO checkPhoneRepeat(@Param("userId")Integer userId, @Param("phone")String phone);

    //校验身份证是否重复
    SysUserRbacDTO checkIdcardRepeat(@Param("userId")Integer userId, @Param("Idcard")String Idcard);

    /**
     * 查询详情
     * @param id
     * @return
     */
    MemInfo selectDetailById(@Param("businessId")int businessId);

    /**
     * 查询最大的会员号
     * @return
     */
    String selectMaxCode();

    /**
     * 查询加密字段
     * @param businessId
     * @return
     */
    MemInfo getUserPhone(Integer businessId);

    IPage<opmArticleDTO> queryOpmArticlesPaged(CyPageInfo cyPageInfo,@Param("entity") opmArticleDTO opmArticleDTO);

    String getRegisterNumber(@Param("entity") peopleNumberDTO peopleNumberDTO);

    String getRealNumber(@Param("entity") peopleNumberDTO peopleNumberDTO);

    String getActivityNumber(@Param("entity") peopleNumberDTO peopleNumberDTO);

    String getArticleNumber(@Param("entity") peopleNumberDTO peopleNumberDTO);

    List<CmsActivity> getCmsActivityList(@Param("entity") peopleNumberDTO peopleNumberDTO);

    List<opmArticleDTO> getArticleCountByDateRangeYes(@Param("startDate") LocalDate startDate,@Param("endDate") LocalDate endDate);

    List<opmArticleDTO> getArticleCountByMonthRangeYes(@Param("startDateMonth")LocalDate startDateMonth,@Param("endDate") LocalDate endDate);

    List<opmArticleDTO> getArticleCountByDateRangeNo(@Param("startDate") LocalDate startDate,@Param("endDate") LocalDate endDate);

    List<opmArticleDTO> getArticleCountByMonthRangeNo(@Param("startDateMonth")LocalDate startDateMonth,@Param("endDate") LocalDate endDate);

    /**
     * 查询加密字段
     * @param userId
     * @return
     */
    MemInfo getInfoByUserId(String userId);

    /**
     * 根据openid查询用户信息
     * @param openId
     * @return
     */
    MemInfo selectByOpenId(String openId);

    /**
     * 关注
     */
    Integer addFollow(@Param("entity") MemFollowDTO followDTO);

    /**
     * 查看是否已关注
     */
    MemFollowDTO getIsFollow(@Param("entity") MemFollowDTO followDTO);

    /**
     * 删除关注
     */
    Integer deleteFollow(@Param("entity") MemFollowDTO followDTO);

    /**
     * 点赞
     */
    Integer addLike(@Param("entity") MemLikeDTO likeDTO);

    /**
     * 查询关注的id集合
     */
    List<Integer> queryFollowIdById(String authenBusinessId);

    /**
     * 排行榜
     */
    IPage<MemInfo> queryRankPaged(CyPageInfo cyPageInfo,@Param("entity") MemInfo memInfo);
}

